@@ -271,16 +271,23 @@ def generate_substitutions_from_package(
     # Resolve dependencies
     depends = package.run_depends + package.buildtool_export_depends
     build_depends = package.build_depends + package.buildtool_depends + package.test_depends
-    unresolved_keys = depends + build_depends
+    unresolved_keys = depends + build_depends + package.replaces + package.conflicts
     resolved_deps = resolve_dependencies(unresolved_keys, os_name,
                                          os_version, ros_distro,
-                                         peer_packages, fallback_resolver)
+                                         peer_packages + [d.name for d in package.replaces + package.conflicts],
+                                         fallback_resolver)
     data['Depends'] = sorted(
         set(format_depends(depends, resolved_deps))
     )
     data['BuildDepends'] = sorted(
         set(format_depends(build_depends, resolved_deps))
     )
+    data['Replaces'] = sorted(
+        set(format_depends(package.replaces, resolved_deps))
+    )
+    data['Conflicts'] = sorted(
+        set(format_depends(package.conflicts, resolved_deps))
+    )
     # Set the distribution
     data['Distribution'] = os_version
     # Use the time stamp to set the date strings
@@ -554,7 +561,8 @@ class DebianGenerator(BloomGenerator):
             for os_version in self.distros:
                 resolve_dependencies(unresolved_keys, self.os_name,
                                      os_version, self.rosdistro,
-                                     peer_packages, fallback_resolver=missing_dep_resolver)
+                                     peer_packages + [d.name for d in package.replaces + package.conflicts],
+                                     fallback_resolver=missing_dep_resolver)
 
         info("All keys are " + ansi('greenf') + "OK" + ansi('reset') + "\n")
 
@@ -667,16 +675,18 @@ class DebianGenerator(BloomGenerator):
         # Create/Clean the debian folder
         if os.path.exists(debian_dir):
             if self.interactive:
-                warning("Debian directory exists: " + debian_dir)
+                warning("debian directory exists: " + debian_dir)
                 warning("Do you wish to overwrite it?")
                 if not maybe_continue('y'):
                     error("Answered no to continue, aborting.", exit=True)
+            elif 'BLOOM_CLEAR_DEBIAN_ON_GENERATION' in os.environ:
+                warning("Overwriting debian directory: " + debian_dir)
+                execute_command('git rm -rf ' + debian_dir)
+                execute_command('git commit -m "Clearing previous debian folder"')
+                if os.path.exists(debian_dir):
+                    shutil.rmtree(debian_dir)
             else:
-                warning("Overwriting Debian directory: " + debian_dir)
-            execute_command('git rm -rf ' + debian_dir)
-            execute_command('git commit -m "Clearing previous debian folder"')
-            if os.path.exists(debian_dir):
-                shutil.rmtree(debian_dir)
+                warning("Not overwriting debian directory.")
         # Use generic place template files command
         place_template_files('.', gbp=True)
         # Commit results
